==> prism-0.0.2.tgz: package/src/components/prism-php.js <==
import Prism from './prism-core'
import './prism-markup'
import './prism-markup-templating'
/**
 * Original by Aaron Harun: http://aahacreative.com/2012/07/31/php-syntax-highlighting-prism/
 * Modified by Miles Johnson: http://milesj.me
 * Rewritten by Tom Pavelec
 *
 * Supports PHP 5.3 - 8.0
 */
var comment = /\/\*[\s\S]*?\*\/|\/\/.*|#(?!\[).*/
var constant = [
  {
    pattern: /\b(?:false|true)\b/i,
    alias: 'boolean',
  },
  /\b[A-Z_][A-Z0-9_]*\b(?!\s*\()/,
  /\b(?:null)\b/i,
]
var number = /\b0b[01]+(?:_[01]+)*\b|\b0o[0-7]+(?:_[0-7]+)*\b|\b0x[\da-f]+(?:_[\da-f]+)*\b|(?:\b\d+(?:_\d+)*\.?(?:\d+(?:_\d+)*)?|\B\.\d+)(?:e[+-]?\d+)?/i
var operator = /<?=>|\?\?=?|\.{3}|\??->|[!=]=?=?|::|\*\*=?|--|\+\+|&&|\|\||<<|>>|[?~]|[/^|%*&<>.+-]=?/
var punctuation = /[{}\[\](),:;]/

Prism.languages.php = {
  delimiter: {
    pattern: /\?>$|^<\?(?:php(?=\s)|=)?/i,
    alias: 'important',
  },
  comment: comment,
  variable: /\$+(?:\w+\b|(?={))/i,
  package: {
    pattern: /(namespace\s+|use\s+(?:function\s+)?)(?:\\?\b[a-z_]\w*)+\b(?!\\)/i,
    lookbehind: true,
    inside: {
      punctuation: /\\/,
    },
  },
  'class-name-definition': {
    pattern: /(\b(?:class|interface|trait)\s+)\b[a-z_]\w*(?!\\)\b/i,
    lookbehind: true,
    alias: 'class-name',
  },
  keyword: [
    {
      pattern: /(\(\s*)\b(?:bool|boolean|int|integer|float|string|object|array)\b(?=\s*\))/i,
      alias: 'type-casting',
      greedy: true,
      lookbehind: true,
    },
    {
      pattern: /([(,?]\s*)\b(?:bool|int|float|string|object|array(?!\s*\()|mixed|self|static|callable|iterable|(?:null|false)(?=\s*\|))\b(?=\s*\$)/i,
      alias: 'type-hint',
      greedy: true,
      lookbehind: true,
    },
    {
      pattern: /([(,?]\s*[a-z0-9_|]\|\s*)(?:null|false)\b(?=\s*\$)/i,
      alias: 'type-hint',
      greedy: true,
      lookbehind: true,
    },
    {
      pattern: /(\)\s*:\s*(?:\?\s*)?)\b(?:bool|int|float|string|object|void|array(?!\s*\()|mixed|self|static|callable|iterable|(?:null|false)(?=\s*\|))\b/i,
      alias: 'return-type',
      greedy: true,
      lookbehind: true,
    },
    {
      pattern: /(\)\s*:\s*(?:\?\s*)?[a-z0-9_|]\|\s*)(?:null|false)\b/i,
      alias: 'return-type',
      greedy: true,
      lookbehind: true,
    },
    {
      pattern: /\b(?:bool|int|float|string|object|void|array(?!\s*\()|mixed|iterable|(?:null|false)(?=\s*\|))\b/i,
      alias: 'type-declaration',
      greedy: true,
    },
    {
      pattern: /(\|\s*)(?:null|false)\b/i,
      alias: 'type-declaration',
      greedy: true,
      lookbehind: true,
    },
    {
      pattern: /\b(?:parent|self|static)(?=\s*::)/i,
      alias: 'static-context',
      greedy: true,
    },
    /\b(?:__halt_compiler|abstract|and|array|as|break|callable|case|catch|class|clone|const|continue|declare|default|die|do|echo|else|elseif|empty|enddeclare|endfor|endforeach|endif|endswitch|endwhile|eval|exit|extends|final|finally|for|foreach|function|global|goto|if|implements|include|include_once|instanceof|insteadof|interface|isset|list|namespace|match|new|or|parent|print|private|protected|public|require|require_once|return|self|static|switch|throw|trait|try|unset|use|var|while|xor|yield)\b/i,
  ],
  'argument-name': /\b[a-z_]\w*(?=\s*:(?!:))/i,
  'class-name': [
    {
      pattern: /(\b(?:extends|implements|instanceof|new(?!\s+self|\s+static))\s+|\bcatch\s*\()\b[a-z_]\w*(?!\\)\b/i,
      greedy: true,
      lookbehind: true,
    },
    {
      pattern: /(\|\s*)\b[a-z_]\w*(?!\\)\b/i,
      greedy: true,
      lookbehind: true,
    },
    {
      pattern: /\b[a-z_]\w*(?!\\)\b(?=\s*\|)/i,
      greedy: true,
    },
    {
      pattern: /(\|\s*)(?:\\?\b[a-z_]\w*)+\b/i,
      alias: 'class-name-fully-qualified',
      greedy: true,
      lookbehind: true,
      inside: {
        punctuation: /\\/,
      },
    },
    {
      pattern: /(?:\\?\b[a-z_]\w*)+\b(?=\s*\|)/i,
      alias: 'class-name-fully-qualified',
      greedy: true,
      inside: {
        punctuation: /\\/,
      },
    },
    {
      pattern: /(\b(?:extends|implements|instanceof|new(?!\s+self\b|\s+static\b))\s+|\bcatch\s*\()(?:\\?\b[a-z_]\w*)+\b(?!\\)/i,
      alias: 'class-name-fully-qualified',
      greedy: true,
      lookbehind: true,
      inside: {
        punctuation: /\\/,
      },
    },
    {
      pattern: /\b[a-z_]\w*(?=\s*\$)/i,
      alias: 'type-declaration',
      greedy: true,
    },
    {
      pattern: /(?:\\?\b[a-z_]\w*)+(?=\s*\$)/i,
      alias: ['class-name-fully-qualified', 'type-declaration'],
      greedy: true,
      inside: {
        punctuation: /\\/,
      },
    },
    {
      pattern: /\b[a-z_]\w*(?=\s*::)/i,
      alias: 'static-context',
      greedy: true,
    },
    {
      pattern: /(?:\\?\b[a-z_]\w*)+(?=\s*::)/i,
      alias: ['class-name-fully-qualified', 'static-context'],
      greedy: true,
      inside: {
        punctuation: /\\/,
      },
    },
    {
      pattern: /([(,?]\s*)[a-z_]\w*(?=\s*\$)/i,
      alias: 'type-hint',
      greedy: true,
      lookbehind: true,
    },
    {
      pattern: /([(,?]\s*)(?:\\?\b[a-z_]\w*)+(?=\s*\$)/i,
      alias: ['class-name-fully-qualified', 'type-hint'],
      greedy: true,
      lookbehind: true,
      inside: {
        punctuation: /\\/,
      },
    },
    {
      pattern: /(\)\s*:\s*(?:\?\s*)?)\b[a-z_]\w*(?!\\)\b/i,
      alias: 'return-type',
      greedy: true,
      lookbehind: true,
    },
    {
      pattern: /(\)\s*:\s*(?:\?\s*)?)(?:\\?\b[a-z_]\w*)+\b(?!\\)/i,
      alias: ['class-name-fully-qualified', 'return-type'],
      greedy: true,
      lookbehind: true,
      inside: {
        punctuation: /\\/,
      },
    },
  ],
  constant: constant,
  function: /\w+\s*(?=\()/,
  property: {
    pattern: /(->)[\w]+/,
    lookbehind: true,
  },
  number: number,
  operator: operator,
  punctuation: punctuation,
}

var string_interpolation = {
  pattern: /{\$(?:{(?:{[^{}]+}|[^{}]+)}|[^{}])+}|(^|[^\\{])\$+(?:\w+(?:\[[^\r\n\[\]]+\]|->\w+)*)/,
  lookbehind: true,
  inside: Prism.languages.php,
}

var string = [
  {
    pattern: /<<<'([^']+)'[\r\n](?:.*[\r\n])*?\1;/,
    alias: 'nowdoc-string',
    greedy: true,
    inside: {
      delimiter: {
        pattern: /^<<<'[^']+'|[a-z_]\w*;$/i,
        alias: 'symbol',
        inside: {
          punctuation: /^<<<'?|[';]$/,
        },
      },
    },
  },
  {
    pattern: /<<<(?:"([^"]+)"[\r\n](?:.*[\r\n])*?\1;|([a-z_]\w*)[\r\n](?:.*[\r\n])*?\2;)/i,
    alias: 'heredoc-string',
    greedy: true,
    inside: {
      delimiter: {
        pattern: /^<<<(?:"[^"]+"|[a-z_]\w*)|[a-z_]\w*;$/i,
        alias: 'symbol',
        inside: {
          punctuation: /^<<<"?|[";]$/,
        },
      },
      interpolation: string_interpolation, // See below
    },
  },
  {
    pattern: /`(?:\\[\s\S]|[^\\`])*`/,
    alias: 'backtick-quoted-string',
    greedy: true,
  },
  {
    pattern: /'(?:\\[\s\S]|[^\\'])*'/,
    alias: 'single-quoted-string',
    greedy: true,
  },
  {
    pattern: /"(?:\\[\s\S]|[^\\"])*"/,
    alias: 'double-quoted-string',
    greedy: true,
    inside: {
      interpolation: string_interpolation, // See below
    },
  },
]

Prism.languages.insertBefore('php', 'variable', {
  string: string,
})

Prism.languages.insertBefore('php', 'variable', {
  attribute: {
    pattern: /#\[(?:[^"'\/#]|\/(?![*/])|\/\/.*$|#(?!\[).*$|\/\*(?:[^*]|\*(?!\/))*\*\/|"(?:\\[\s\S]|[^\\"])*"|'(?:\\[\s\S]|[^\\'])*')+\](?=\s*[a-z$#])/im,
    greedy: true,
    inside: {
      'attribute-content': {
        pattern: /^(#\[)[\s\S]+(?=]$)/,
        lookbehind: true,
        // inside can appear subset of php
        inside: {
          comment: comment,
          string: string,
          'attribute-class-name': [
            {
              pattern: /([^:]|^)\b[a-z_]\w*(?!\\)\b/i,
              alias: 'class-name',
              greedy: true,
              lookbehind: true,
            },
            {
              pattern: /([^:]|^)(?:\\?\b[a-z_]\w*)+/i,
              alias: ['class-name', 'class-name-fully-qualified'],
              greedy: true,
              lookbehind: true,
              inside: {
                punctuation: /\\/,
              },
            },
          ],
          constant: constant,
          number: number,
          operator: operator,
          punctuation: punctuation,
        },
      },
      delimiter: {
        pattern: /^#\[|]$/,
        alias: 'punctuation',
      },
    },
  },
})

Prism.hooks.add('before-tokenize', function (env) {
  if (!/<\?/.test(env.code)) {
    return
  }

  var phpPattern = /<\?(?:[^"'/#]|\/(?![*/])|("|')(?:\\[\s\S]|(?!\1)[^\\])*\1|(?:\/\/|#(?!\[))(?:[^?\n\r]|\?(?!>))*(?=$|\?>|[\r\n])|#\[|\/\*(?:[^*]|\*(?!\/))*(?:\*\/|$))*?(?:\?>|$)/gi
  Prism.languages['markup-templating'].buildPlaceholders(env, 'php', phpPattern)
})

Prism.hooks.add('after-tokenize', function (env) {
  Prism.languages['markup-templating'].tokenizePlaceholders(env, 'php')
})

==> prism-0.0.3.tgz: package/src/components/prism-php.js <==
import Prism from './prism-core'
import './prism-markup'
import './prism-markup-templating'
/**
 * Original by Aaron Harun: http://aahacreative.com/2012/07/31/php-syntax-highlighting-prism/
 * Modified by Miles Johnson: http://milesj.me
 * Rewritten by Tom Pavelec
 *
 * Supports PHP 5.3 - 8.0
 */
var comment = /\/\*[\s\S]*?\*\/|\/\/.*|#(?!\[).*/
var constant = [
  {
    pattern: /\b(?:false|true)\b/i,
    alias: 'boolean',
  },
  /\b[A-Z_][A-Z0-9_]*\b(?!\s*\()/,
  /\b(?:null)\b/i,
]
var number = /\b0b[01]+(?:_[01]+)*\b|\b0o[0-7]+(?:_[0-7]+)*\b|\b0x[\da-f]+(?:_[\da-f]+)*\b|(?:\b\d+(?:_\d+)*\.?(?:\d+(?:_\d+)*)?|\B\.\d+)(?:e[+-]?\d+)?/i
var operator = /<?=>|\?\?=?|\.{3}|\??->|[!=]=?=?|::|\*\*=?|--|\+\+|&&|\|\||<<|>>|[?~]|[/^|%*&<>.+-]=?/
var punctuation = /[{}\[\](),:;]/

Prism.languages.php = {
  delimiter: {
    pattern: /\?>$|^<\?(?:php(?=\s)|=)?/i,
    alias: 'important',
  },
  comment: comment,
  variable: /\$+(?:\w+\b|(?={))/i,
  package: {
    pattern: /(namespace\s+|use\s+(?:function\s+)?)(?:\\?\b[a-z_]\w*)+\b(?!\\)/i,
    lookbehind: true,
    inside: {
      punctuation: /\\/,
    },
  },
  'class-name-definition': {
    pattern: /(\b(?:class|interface|trait)\s+)\b[a-z_]\w*(?!\\)\b/i,
    lookbehind: true,
    alias: 'class-name',
  },
  keyword: [
    {
      pattern: /(\(\s*)\b(?:bool|boolean|int|integer|float|string|object|array)\b(?=\s*\))/i,
      alias: 'type-casting',
      greedy: true,
      lookbehind: true,
    },
    {
      pattern: /([(,?]\s*)\b(?:bool|int|float|string|object|array(?!\s*\()|mixed|self|static|callable|iterable|(?:null|false)(?=\s*\|))\b(?=\s*\$)/i,
      alias: 'type-hint',
      greedy: true,
      lookbehind: true,
    },
    {
      pattern: /([(,?]\s*[a-z0-9_|]\|\s*)(?:null|false)\b(?=\s*\$)/i,
      alias: 'type-hint',
      greedy: true,
      lookbehind: true,
    },
    {
      pattern: /(\)\s*:\s*(?:\?\s*)?)\b(?:bool|int|float|string|object|void|array(?!\s*\()|mixed|self|static|callable|iterable|(?:null|false)(?=\s*\|))\b/i,
      alias: 'return-type',
      greedy: true,
      lookbehind: true,
    },
    {
      pattern: /(\)\s*:\s*(?:\?\s*)?[a-z0-9_|]\|\s*)(?:null|false)\b/i,
      alias: 'return-type',
      greedy: true,
      lookbehind: true,
    },
    {
      pattern: /\b(?:bool|int|float|string|object|void|array(?!\s*\()|mixed|iterable|(?:null|false)(?=\s*\|))\b/i,
      alias: 'type-declaration',
      greedy: true,
    },
    {
      pattern: /(\|\s*)(?:null|false)\b/i,
      alias: 'type-declaration',
      greedy: true,
      lookbehind: true,
    },
    {
      pattern: /\b(?:parent|self|static)(?=\s*::)/i,
      alias: 'static-context',
      greedy: true,
    },
    /\b(?:__halt_compiler|abstract|and|array|as|break|callable|case|catch|class|clone|const|continue|declare|default|die|do|echo|else|elseif|empty|enddeclare|endfor|endforeach|endif|endswitch|endwhile|eval|exit|extends|final|finally|for|foreach|function|global|goto|if|implements|include|include_once|instanceof|insteadof|interface|isset|list|namespace|match|new|or|parent|print|private|protected|public|require|require_once|return|self|static|switch|throw|trait|try|unset|use|var|while|xor|yield)\b/i,
  ],
  'argument-name': /\b[a-z_]\w*(?=\s*:(?!:))/i,
  'class-name': [
    {
      pattern: /(\b(?:extends|implements|instanceof|new(?!\s+self|\s+static))\s+|\bcatch\s*\()\b[a-z_]\w*(?!\\)\b/i,
      greedy: true,
      lookbehind: true,
    },
    {
      pattern: /(\|\s*)\b[a-z_]\w*(?!\\)\b/i,
      greedy: true,
      lookbehind: true,
    },
    {
      pattern: /\b[a-z_]\w*(?!\\)\b(?=\s*\|)/i,
      greedy: true,
    },
    {
      pattern: /(\|\s*)(?:\\?\b[a-z_]\w*)+\b/i,
      alias: 'class-name-fully-qualified',
      greedy: true,
      lookbehind: true,
      inside: {
        punctuation: /\\/,
      },
    },
    {
      pattern: /(?:\\?\b[a-z_]\w*)+\b(?=\s*\|)/i,
      alias: 'class-name-fully-qualified',
      greedy: true,
      inside: {
        punctuation: /\\/,
      },
    },
    {
      pattern: /(\b(?:extends|implements|instanceof|new(?!\s+self\b|\s+static\b))\s+|\bcatch\s*\()(?:\\?\b[a-z_]\w*)+\b(?!\\)/i,
      alias: 'class-name-fully-qualified',
      greedy: true,
      lookbehind: true,
      inside: {
        punctuation: /\\/,
      },
    },
    {
      pattern: /\b[a-z_]\w*(?=\s*\$)/i,
      alias: 'type-declaration',
      greedy: true,
    },
    {
      pattern: /(?:\\?\b[a-z_]\w*)+(?=\s*\$)/i,
      alias: ['class-name-fully-qualified', 'type-declaration'],
      greedy: true,
      inside: {
        punctuation: /\\/,
      },
    },
    {
      pattern: /\b[a-z_]\w*(?=\s*::)/i,
      alias: 'static-context',
      greedy: true,
    },
    {
      pattern: /(?:\\?\b[a-z_]\w*)+(?=\s*::)/i,
      alias: ['class-name-fully-qualified', 'static-context'],
      greedy: true,
      inside: {
        punctuation: /\\/,
      },
    },
    {
      pattern: /([(,?]\s*)[a-z_]\w*(?=\s*\$)/i,
      alias: 'type-hint',
      greedy: true,
      lookbehind: true,
    },
    {
      pattern: /([(,?]\s*)(?:\\?\b[a-z_]\w*)+(?=\s*\$)/i,
      alias: ['class-name-fully-qualified', 'type-hint'],
      greedy: true,
      lookbehind: true,
      inside: {
        punctuation: /\\/,
      },
    },
    {
      pattern: /(\)\s*:\s*(?:\?\s*)?)\b[a-z_]\w*(?!\\)\b/i,
      alias: 'return-type',
      greedy: true,
      lookbehind: true,
    },
    {
      pattern: /(\)\s*:\s*(?:\?\s*)?)(?:\\?\b[a-z_]\w*)+\b(?!\\)/i,
      alias: ['class-name-fully-qualified', 'return-type'],
      greedy: true,
      lookbehind: true,
      inside: {
        punctuation: /\\/,
      },
    },
  ],
  constant: constant,
  function: /\w+\s*(?=\()/,
  property: {
    pattern: /(->)[\w]+/,
    lookbehind: true,
  },
  number: number,
  operator: operator,
  punctuation: punctuation,
}

var string_interpolation = {
  pattern: /{\$(?:{(?:{[^{}]+}|[^{}]+)}|[^{}])+}|(^|[^\\{])\$+(?:\w+(?:\[[^\r\n\[\]]+\]|->\w+)*)/,
  lookbehind: true,
  inside: Prism.languages.php,
}

var string = [
  {
    pattern: /<<<'([^']+)'[\r\n](?:.*[\r\n])*?\1;/,
    alias: 'nowdoc-string',
    greedy: true,
    inside: {
      delimiter: {
        pattern: /^<<<'[^']+'|[a-z_]\w*;$/i,
        alias: 'symbol',
        inside: {
          punctuation: /^<<<'?|[';]$/,
        },
      },
    },
  },
  {
    pattern: /<<<(?:"([^"]+)"[\r\n](?:.*[\r\n])*?\1;|([a-z_]\w*)[\r\n](?:.*[\r\n])*?\2;)/i,
    alias: 'heredoc-string',
    greedy: true,
    inside: {
      delimiter: {
        pattern: /^<<<(?:"[^"]+"|[a-z_]\w*)|[a-z_]\w*;$/i,
        alias: 'symbol',
        inside: {
          punctuation: /^<<<"?|[";]$/,
        },
      },
      interpolation: string_interpolation, // See below
    },
  },
  {
    pattern: /`(?:\\[\s\S]|[^\\`])*`/,
    alias: 'backtick-quoted-string',
    greedy: true,
  },
  {
    pattern: /'(?:\\[\s\S]|[^\\'])*'/,
    alias: 'single-quoted-string',
    greedy: true,
  },
  {
    pattern: /"(?:\\[\s\S]|[^\\"])*"/,
    alias: 'double-quoted-string',
    greedy: true,
    inside: {
      interpolation: string_interpolation, // See below
    },
  },
]

Prism.languageUtils.insertBefore('php', 'variable', {
  string: string,
})

Prism.languageUtils.insertBefore('php', 'variable', {
  attribute: {
    pattern: /#\[(?:[^"'\/#]|\/(?![*/])|\/\/.*$|#(?!\[).*$|\/\*(?:[^*]|\*(?!\/))*\*\/|"(?:\\[\s\S]|[^\\"])*"|'(?:\\[\s\S]|[^\\'])*')+\](?=\s*[a-z$#])/im,
    greedy: true,
    inside: {
      'attribute-content': {
        pattern: /^(#\[)[\s\S]+(?=]$)/,
        lookbehind: true,
        // inside can appear subset of php
        inside: {
          comment: comment,
          string: string,
          'attribute-class-name': [
            {
              pattern: /([^:]|^)\b[a-z_]\w*(?!\\)\b/i,
              alias: 'class-name',
              greedy: true,
              lookbehind: true,
            },
            {
              pattern: /([^:]|^)(?:\\?\b[a-z_]\w*)+/i,
              alias: ['class-name', 'class-name-fully-qualified'],
              greedy: true,
              lookbehind: true,
              inside: {
                punctuation: /\\/,
              },
            },
          ],
          constant: constant,
          number: number,
          operator: operator,
          punctuation: punctuation,
        },
      },
      delimiter: {
        pattern: /^#\[|]$/,
        alias: 'punctuation',
      },
    },
  },
})

Prism.hooks.add('before-tokenize', function (env) {
  if (!/<\?/.test(env.code)) {
    return
  }

  var phpPattern = /<\?(?:[^"'/#]|\/(?![*/])|("|')(?:\\[\s\S]|(?!\1)[^\\])*\1|(?:\/\/|#(?!\[))(?:[^?\n\r]|\?(?!>))*(?=$|\?>|[\r\n])|#\[|\/\*(?:[^*]|\*(?!\/))*(?:\*\/|$))*?(?:\?>|$)/gi
  Prism.languages['markup-templating'].buildPlaceholders(env, 'php', phpPattern)
})

Prism.hooks.add('after-tokenize', function (env) {
  Prism.languages['markup-templating'].tokenizePlaceholders(env, 'php')
})
